CREATE PROCEDURE ACCNT_ReturnRights (
	@sPrintMe		CHAR(1),
	@sOwnTrans		CHAR(1),
	@sRtnMsg		VARCHAR(75) = NULL OUTPUT,

	/* other vars with descriptions */
	@iRightsLvl			VARCHAR(255) = '',		/* Rights level name to see if the user has */
	@iLoginAccountUnq	INT = -1,				/* The user to check the right for */
	@sGroupType			CHAR(3) = '',			/* This is "S", "R", or "" */
	@bHasAccount		NVARCHAR,					/* This is "T" if the user has an account, or "F" otherwise */
	@iDomainName		INT = 0,
	@sGlobalRotations	INT = 0,
	@sGlobalDateBegin	VARCHAR(32) = '',
	@sGlobalGroupUnq	INT = 0,
	@sGlobalPosition	INT = 0,
	@iGlobalNumDays		INT = 0,
	@sHasRight			CHAR(1) = NULL OUTPUT	/* This is a "Y" if the user has the right, or "N" otherwise */
) 

AS

/* Additional variables used in this procedure */
DECLARE
	@sIntransaction  	CHAR(1),		/* Indicate finalization routine to commit or rollback */
	@iRtnCode    		INT,			/* Return 0 for success, prefer positive values for failure */
	@iTotal				INT,
	@iTotalDays			INT,
	@x					INT,
	@y					INT,
	@z					INT,
	@a					INT,
	@dDate				SMALLDATETIME

/* Initialize the main variables in use */
SELECT @iRtnCode = 0, @sInTransaction = 'N', @sHasRight = 'N'

/* Make sure inputs are there */
IF @iRightsLvl = '' BEGIN
	GOTO Proc_Finalize
END

/* They must have an account */	
IF @bHasAccount <> 'T' BEGIN
	GOTO Proc_Finalize
END

IF @iLoginAccountUnq = -1 BEGIN
	GOTO Proc_Finalize
END
	
/* must be one of three things */
IF ( @sGroupType <> '' AND @sGroupType <> 'S' AND @sGroupType <> 'R' ) BEGIN
	GOTO Proc_Finalize
END

/* Start the transaction if appropriate */
IF @sOwnTrans = 'Y' BEGIN
	BEGIN TRANSACTION
	SELECT @sInTransaction = 'Y'
END

IF ( @sGroupType = '' OR @sGroupType = 'S' ) 
	BEGIN
		/* they are in a Standard Group or no Group at all */
		IF EXISTS (SELECT AccountUnq, RightsLvl FROM Rights (NOLOCK) WHERE 
						RightsLvl = @iRightsLvl AND 
						AccountUnq = @iLoginAccountUnq AND 
						DomainUnq = @iDomainName AND 
							(RevokeDate IS NULL OR 
								RevokeDate < GrantDate) 
					UNION 
						SELECT R.AccountUnq, R.RightsLvl FROM Rights R (NOLOCK), GroupMap M (NOLOCK), Groups G (NOLOCK) WHERE 
							G.Type = 'S' AND 
							G.GroupUnq = M.GroupUnq AND 
							M.DomainUnq = @iDomainName AND 
							M.DomainUnq = G.DomainUnq AND 
							M.GroupUnq = R.GroupUnq AND 
							M.AccountUnq = @iLoginAccountUnq AND 
							R.DomainUnq = @iDomainName AND 
								(R.RevokeDate IS NULL OR 
									R.RevokeDate < R.GrantDate) AND 
							R.RightsLvl = @iRightsLvl)
		BEGIN
			SELECT @sHasRight = 'Y'
			GOTO Proc_Finalize
		END ELSE
		BEGIN
			SELECT @sHasRight = 'N'
			GOTO Proc_Finalize
		END
	END
ELSE
	BEGIN
		IF EXISTS (SELECT * FROM Rights (NOLOCK) WHERE 
						RightsLvl = @iRightsLvl AND 
						AccountUnq = @iLoginAccountUnq AND 
						DomainUnq = @iDomainName AND 
							(RevokeDate IS NULL OR 
								RevokeDate < GrantDate))
		BEGIN
			/* They have the rights level independent of the Rotational Group so do not bother checking */
			SELECT @sHasRight = 'Y'
			GOTO Proc_Finalize
		END ELSE
		BEGIN
			/* Check to see if the Rotational Group they are in has the rights - this must be done seperate from getting the */
			/*	sum of the days in the rotation because if the start date and login date and today are all the same, it */
			/*	looks just like the rights level exists too - even if it doesn't! */
			IF EXISTS (SELECT * FROM Rights (NOLOCK) WHERE 
							GroupUnq = @sGlobalGroupUnq AND 
							RightsLvl = @iRightsLvl AND 
							AccountUnq = 0 AND 
							DomainUnq = @iDomainName AND 
								(RevokeDate IS NULL OR 
								RevokeDate < GrantDate))
			BEGIN
				/* They are in a Rotational Group, so check that one */
				/* Get the total # of days up to the current day */
				SELECT @iTotal = ISNULL(SUM(M.NumDays),0) FROM GroupMap M (NOLOCK), Rights R (NOLOCK) WHERE 
					M.GroupUnq = @sGlobalGroupUnq AND 
					M.GroupUnq = R.GroupUnq AND 
					M.Position <= @sGlobalPosition AND 
					R.RightsLvl = @iRightsLvl AND 
					M.DomainUnq = @iDomainName
				/*  Get the total # of days for a rotation */
				SELECT @iTotalDays = SUM(NumDays) FROM GroupMap (NOLOCK) WHERE 
					GroupUnq = @sGlobalGroupUnq AND 
					DomainUnq = @iDomainName
					/* # days from start date to now  x = DateDiff("d", CDate(sGlobalDateBegin), Now) */
					/* divide that by # rotations	y = Int(x / sGlobalRotations) */
					/* if int part is less than # of rotations then keep going, otherwise it's past already so its false */
					/* multiply that int part by # days per rotation	z = y * iTotalDays */
					/* add that and the # days up to current day	a = z + @iTotal */
					/* add that number of days to the start date	dDate = DateAdd("d", a, sGlobalDateBegin) */
					/* if that date is today then it's true	if dDate=now then true */
					SELECT @x = DATEDIFF(day, @sGlobalDateBegin, GETDATE())
					SELECT @y = FLOOR(@x / @iTotalDays)
					IF ( @y < 0 )
					BEGIN
						SELECT @y = 0
					END
					IF ( @y < @sGlobalRotations )
					BEGIN
						SELECT @z = @y * @iTotalDays
						SELECT @a = @z + @iTotal
						SELECT @dDate = DATEADD(day, @a, @sGlobalDateBegin)
						IF ( @dDate >= GETDATE() ) AND
							( @dDate <= DATEADD(day, @iGlobalNumDays, GETDATE()) )
							BEGIN
								SELECT @sHasRight = 'Y'
								GOTO Proc_Finalize
							END ELSE
							BEGIN
								SELECT @sHasRight = 'N'
								GOTO Proc_Finalize
							END
					END ELSE
					BEGIN
						SELECT @sHasRight = 'N'
						GOTO Proc_Finalize
					END
			END ELSE
			BEGIN
				/* the rights are not in that group at all */
				SELECT @sHasRight = 'N'
				GOTO Proc_Finalize
			END
		END
	END



Proc_Finalize:
/* Do we commit here or not */
IF @sInTransaction = 'Y' BEGIN
	IF @iRtnCode = 0
		COMMIT TRANSACTION
	ELSE
		ROLLBACK TRANSACTION
END

/* Create a recordset output if requested */
IF @sPrintMe = 'Y'
	SELECT @iRtnCode "RtnCode", @sRtnMsg "RtnMessage", @sHasRight "sHasRight"

RETURN @iRtnCode