CREATE PROCEDURE DOMAIN_DelDomain_A (
	@sDomainUnq			INT = 0,		/* The DomainUnq of the domain to delete */
	@iDomainUnq			INT = 0,		/* The DomainUnq of the domain we are deleting it from - for logging purposes only */
	@iAccountUnq		INT = 0			/* The AccountUnq of the user deleting the domain - for logging */
)
WITH ENCRYPTION
AS

/* Additional variables used in this procedure */
DECLARE
	@iRtnCode    		INT,				/* Return 0 for success, prefer positive values for failure */
	@sTempDomainName	VARCHAR(255),
	@sTempDesc			VARCHAR(255),
	@sTempGroupUnq		INT


/* Initialize the main variables in use */
SELECT @iRtnCode = 0

If @sDomainUnq = 0 BEGIN
	GOTO Proc_Finalize
END



/* log the removal of ADVs */
INSERT INTO LogData SELECT @iDomainUnq, 46, MapName, @sDomainUnq, '', 0, '', 0, 'V', @iAccountUnq, GetDate(), 'D', MapName, '' FROM AccountMap WHERE DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 47, MapName, @sDomainUnq, '', 0, '', 0, 'V', @iAccountUnq, GetDate(), 'D', Description, '' FROM AccountMap WHERE DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 48, MapName, @sDomainUnq, '', 0, '', 0, 'V', @iAccountUnq, GetDate(), 'D', Required, '' FROM AccountMap WHERE DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 49, MapName, @sDomainUnq, '', 0, '', 0, 'V', @iAccountUnq, GetDate(), 'D', Visible, '' FROM AccountMap WHERE DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 50, MapName, @sDomainUnq, '', 0, '', 0, 'V', @iAccountUnq, GetDate(), 'D', DataType, '' FROM AccountMap WHERE DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 51, MapName, @sDomainUnq, '', 0, '', 0, 'V', @iAccountUnq, GetDate(), 'D', SystemUnq, '' FROM AccountMap WHERE DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 52, MapName, @sDomainUnq, '', 0, '', 0, 'V', @iAccountUnq, GetDate(), 'D', RightsLvl, '' FROM AccountMap WHERE DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 53, MapName, @sDomainUnq, '', GroupUnq, '', 0, 'V', @iAccountUnq, GetDate(), 'D', MapName, '' FROM AccountMap WHERE DomainUnq = @sDomainUnq


/* log the removal of initial rights */
INSERT INTO LogData SELECT @iDomainUnq, 54, '', @sDomainUnq, '', SystemUnq, '', 0, 'V', @iAccountUnq, GetDate(), 'D', RightsLvl, '' FROM InitialRights WHERE DomainUnq = @sDomainUnq


/* log the removal of all rights from the users */
INSERT INTO LogData SELECT @iDomainUnq, 118, '', AccountUnq, '', @sDomainUnq, '', SystemUnq, 'V', @iAccountUnq, GetDate(), 'D', RightsLvl, '' FROM Rights WHERE DomainUnq = @sDomainUnq AND GroupUnq = 0
INSERT INTO LogData SELECT @iDomainUnq, 119, '', GroupUnq, '', @sDomainUnq, '', SystemUnq, 'V', @iAccountUnq, GetDate(), 'D', RightsLvl, '' FROM Rights WHERE DomainUnq = @sDomainUnq AND AccountUnq = 0


/* log the removal of users from groups */
INSERT INTO LogData SELECT @iDomainUnq, 42, '', AccountUnq, '', @sDomainUnq, '', GroupUnq, 'V', @iAccountUnq, GetDate(), 'D', GroupUnq, '' FROM GroupMap WHERE DomainUnq = @sDomainUnq


/* log the removal of the groups */
INSERT INTO LogData SELECT @sDomainUnq, 42, '', M.AccountUnq, '', @sDomainUnq, '', G.GroupUnq, 'V', @iAccountUnq, GetDate(), 'D', G.GroupUnq, '' FROM Groups G, GroupMap M WHERE G.DomainUnq = @sDomainUnq AND M.GroupUnq = G.GroupUnq AND M.DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 55, '', @sDomainUnq, '', GroupUnq, '', 0, 'V', @iAccountUnq, GetDate(), 'D', Name, '' FROM Groups WHERE DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 57, '', @sDomainUnq, '', GroupUnq, '', 0, 'V', @iAccountUnq, GetDate(), 'D', Rotations, '' FROM Groups WHERE DomainUnq = @sDomainUnq


/* log the removal of the account being able to log onto the domain */
INSERT INTO LogData SELECT @iDomainUnq, 39, '', AccountUnq, '', 0, '', 0, 'V', @iAccountUnq, GetDate(), 'D', DomainUnq, '' FROM AccountDomainMap WHERE DomainUnq = @sDomainUnq

/* log the removal of the mailing lists */
INSERT INTO LogData SELECT @iDomainUnq, 59, '', @sDomainUnq, '', ListUnq, '', 0, 'V', @iAccountUnq, GetDate(), 'D', ListName, '' FROM MailingLists WHERE DomainUnq = @sDomainUnq

/* log the removal of the users from the mailing lists */
INSERT INTO LogData SELECT @iDomainUnq, 45, '', AccountUnq, '', @sDomainUnq, '', ListUnq, 'V', @iAccountUnq, GetDate(), 'D', '', '' FROM ListAccounts WHERE DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 60, '', @sDomainUnq, '', ListUnq, '', AccountUnq, 'V', @iAccountUnq, GetDate(), 'D', IsNull(OptOut,''), '' FROM ListAccounts WHERE DomainUnq = @sDomainUnq


Proc_Finalize:

RETURN @iRtnCode