CREATE PROCEDURE DOMAIN_DelDomain_D (
	@sDomainUnq			INT = 0,		/* The DomainUnq of the domain to delete */
	@iDomainUnq			INT = 0,		/* The DomainUnq of the domain we are deleting it from - for logging purposes only */
	@iAccountUnq		INT = 0			/* The AccountUnq of the user deleting the domain - for logging */
)
WITH ENCRYPTION
AS

/* Additional variables used in this procedure */
DECLARE
	@iRtnCode    		INT,				/* Return 0 for success, prefer positive values for failure */
	@sTempDomainName	VARCHAR(255),
	@sTempDesc			VARCHAR(255),
	@sTempGroupUnq		INT


/* Initialize the main variables in use */
SELECT @iRtnCode = 0

If @sDomainUnq = 0 BEGIN
	GOTO Proc_Finalize
END

/* log the removal of the domain entry */
SELECT @sTempDomainName = Domain, @sTempDesc = Description From DomainInfo (NOLOCK) WHERE DomainUnq = @sDomainUnq
IF NOT @sTempDomainName IS NULL BEGIN
	EXEC DOMAIN_Log @iDomainUnq=@iDomainUnq, @iTypeUnq=20, @sKey1='', @iKey2=@sDomainUnq, @sKey3='', @iKey4=0, @sKey5='', @iKey6=0, @sType='V', @iAccountUnq=@iAccountUnq, @sAction='D', @sVarCharData=@sTempDomainName, @sTextData=''
	EXEC DOMAIN_Log @iDomainUnq=@iDomainUnq, @iTypeUnq=21, @sKey1='', @iKey2=@sDomainUnq, @sKey3='', @iKey4=0, @sKey5='', @iKey6=0, @sType='V', @iAccountUnq=@iAccountUnq, @sAction='D', @sVarCharData=@sTempDesc, @sTextData=''
END
/* DO NOT DELETE FROM DOMAININFO YET -- EVERYTHING ELSE USES IT! */

/* log removal of all conf vars */
INSERT INTO LogData SELECT @iDomainUnq, 4, ConfConst, @sDomainUnq, '', SystemUnq, '', ServerUnq, 'V', @iAccountUnq, GetDate(), 'D', ConfConst, '' FROM Configurations WHERE DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 5, ConfConst, @sDomainUnq, '', SystemUnq, '', ServerUnq, 'V', @iAccountUnq, GetDate(), 'D', Description, '' FROM Configurations WHERE DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 6, ConfConst, @sDomainUnq, '', SystemUnq, '', ServerUnq, 'V', @iAccountUnq, GetDate(), 'D', Value, '' FROM Configurations WHERE DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 7, ConfConst, @sDomainUnq, '', SystemUnq, '', ServerUnq, 'V', @iAccountUnq, GetDate(), 'D', ServerUnq, '' FROM Configurations WHERE DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 8, ConfConst, @sDomainUnq, '', SystemUnq, '', ServerUnq, 'V', @iAccountUnq, GetDate(), 'D', RightLvlv, '' FROM Configurations WHERE DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 9, ConfConst, @sDomainUnq, '', SystemUnq, '', ServerUnq, 'V', @iAccountUnq, GetDate(), 'D', RightLvlc, '' FROM Configurations WHERE DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 125, ConfConst, @sDomainUnq, '', SystemUnq, '', ServerUnq, 'V', @iAccountUnq, GetDate(), 'D', Type, '' FROM Configurations WHERE DomainUnq = @sDomainUnq
DELETE FROM Configurations WHERE DomainUnq = @sDomainUnq

/* log removal of all colors and color schemes */
INSERT INTO LogData SELECT @iDomainUnq, 29, ColorConst, @sDomainUnq, '', SchemeUnq, '', 0, 'V', @iAccountUnq, GetDate(), 'D', ColorConst, '' FROM ColorMap WHERE DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 30, ColorConst, @sDomainUnq, '', SchemeUnq, '', 0, 'V', @iAccountUnq, GetDate(), 'D', ColorConst, '' FROM ColorMap WHERE DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 31, ColorConst, @sDomainUnq, '', SchemeUnq, '', 0, 'V', @iAccountUnq, GetDate(), 'D', Value, '' FROM ColorMap WHERE DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 28, '', @sDomainUnq, '', SchemeUnq, '', 0, 'V', @iAccountUnq, GetDate(), 'D', SchemeName, '' FROM ColorSchemes WHERE DomainUnq = @sDomainUnq
DELETE FROM ColorSchemes WHERE DomainUnq = @sDomainUnq
DELETE FROM ColorMap WHERE DomainUnq = @sDomainUnq

/* log removal of all text constants and text schemes */
INSERT INTO LogData SELECT @iDomainUnq, 32, '', @sDomainUnq, '', SchemeUnq, '', 0, 'V', @iAccountUnq, GetDate(), 'D', SchemeName, '' FROM TextSchemes WHERE DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 33, TextConst, @sDomainUnq, '', SchemeUnq, '', 0, 'V', @iAccountUnq, GetDate(), 'D', VarCharData, '' FROM TextMap WHERE DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 34, TextConst, @sDomainUnq, '', SchemeUnq, '', 0, 'V', @iAccountUnq, GetDate(), 'D', TextConst, '' FROM TextMap WHERE DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 35, TextConst, @sDomainUnq, '', SchemeUnq, '', 0, 'V', @iAccountUnq, GetDate(), 'D', VarCharData, '' FROM TextMap WHERE DomainUnq = @sDomainUnq AND DataType = 'V'
INSERT INTO LogData SELECT @iDomainUnq, 35, TextConst, @sDomainUnq, '', SchemeUnq, '', 0, 'T', @iAccountUnq, GetDate(), 'D', '', TextData FROM TextMap WHERE DomainUnq = @sDomainUnq AND DataType = 'T'
DELETE FROM TextSchemes WHERE DomainUnq = @sDomainUnq
DELETE FROM TextMap WHERE DomainUnq = @sDomainUnq

/* log removal of all actions */
INSERT INTO LogData SELECT @iDomainUnq, 1, ActionsConst, @sDomainUnq, '', SystemUnq, '', 0, 'V', @iAccountUnq, GetDate(), 'D', ActionsConst, '' FROM Actions WHERE DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 2, ActionsConst, @sDomainUnq, '', SystemUnq, '', 0, 'V', @iAccountUnq, GetDate(), 'D', Description, '' FROM Actions WHERE DomainUnq = @sDomainUnq
INSERT INTO LogData SELECT @iDomainUnq, 3, ActionsConst, @sDomainUnq, '', SystemUnq, '', 0, 'T', @iAccountUnq, GetDate(), 'D', '', Code FROM Actions WHERE DomainUnq = @sDomainUnq
DELETE FROM Actions WHERE DomainUnq = @sDomainUnq

/* log the removal from all servers */
INSERT INTO LogData SELECT @iDomainUnq, 22, '', DomainUnq, '', 0, '', 0, 'V', @iAccountUnq, GetDate(), 'D', ServerUnq, '' FROM ServerSites WHERE DomainUnq = @sDomainUnq
DELETE FROM ServerSites WHERE DomainUnq = @sDomainUnq

/* log removal from any group */
SELECT @sTempGroupUnq = GroupUnq FROM DomainGroups (NOLOCK) WHERE DomainUnq = @sDomainUnq
IF NOT @sTempGroupUnq IS NULL BEGIN
	EXEC DOMAIN_Log @iDomainUnq=@iDomainUnq, @iTypeUnq=24, @sKey1='', @iKey2=@sDomainUnq, @sKey3='', @iKey4=@sTempGroupUnq, @sKey5='', @iKey6=0, @sType='V', @iAccountUnq=@iAccountUnq, @sAction='D', @sVarCharData='', @sTextData=''
END
DELETE FROM DomainGroups WHERE DomainUnq = @sDomainUnq


Proc_Finalize:

RETURN @iRtnCode