/* spTemplate.sql - this is a sample proc script to use in creating others*/

IF EXISTS ( SELECT * FROM SysObjects WHERE Type = 'P' AND Name = 'spTemplate' )
	DROP PROCEDURE spTemplate
GO

/* PRINTME returns recordset:			*/
/*		RtnCode			INTEGER,		*/
/*		RtnMessage		VARCHAR(75),	*/
/*		Output1			VARCHAR(200)	*/

CREATE PROCEDURE spTemplate (
	@sPrintMe		CHAR(1),
	@sOwnTrans		CHAR(1),
	@sRtnMsg		VARCHAR(75) = NULL OUTPUT,

	/* other vars with descriptions */
	@sInput1			CHAR(1) = 'Y',			/* sample input */
	@sOutput1			CHAR(1) = NULL OUTPUT,	/* For calling from another Stored Procedure */
	@sTextOutput		TEXT					/* Text Variable must be last - only one allowed */
)
WITH ENCRYPTION
AS

/* Additional variables used in this procedure */
DECLARE
	@sIntransaction  	CHAR(1),		/* Indicate finalization routine to commit or rollback */
	@iRtnCode    		INT				/* Return 0 for success, prefer positive values for failure */


/* Initialize the main variables in use */
SELECT @iRtnCode = 0, @sInTransaction = 'N'



/* Area to perform all qualifications that do not depend on being inside the transaction */
/*		Examples are the existence of the qualified row, duplicate possibility, proper format etc. */
/*		Failures go to Proc_Finalize ...  i.e.  IF NOT EXISTS .... GOTO Proc_Finalize */

/* Start the transaction if appropriate */
IF @sOwnTrans = 'Y' BEGIN
	BEGIN TRANSACTION
	SELECT @sInTransaction = 'Y'
END


/* do something here  for the actual proc*/
/* Critical to assign values to ALL output variables or variable to be used in PrintMe condition */
/* Example */
/*	EXEC @iRtnCode = <Owner>.<Procedure Name> */
/*		@sPrintMe = 'N',					Always No if you use output variables, Yes to read into a temporary table */
/*		@sOwnTrans = 'N',					ALWAYS NO from within another procedure */
/*		@sRtnMsg = @sRtnMsg OUTPUT,	To receive further information */
/*		@sParam = <value or variable>	- String - use hungarian notation */
/*		@iParam = <value or variable - Integer */
/*		@iOutputParam = @iMyVariable OUTPUT - To read the value back from the called procedure */

/*		IF @@ERROR <> 0 BEGIN	*/
/*			SELECT @iRtnCode = 1, @sRtnMsg = 'Procedure <Procedure Name> failed, report to development */
/*			GOTO Proc_Finalize	*/
/*		END	*/
/*		IF @iRtnCode <> 0 */
/*			GOTO Proc_Finalize	*/



Proc_Finalize:
/* Do we commit here or not */
IF @sInTransaction = 'Y' BEGIN
	IF @iRtnCode = 0
		COMMIT TRANSACTION
	ELSE
		ROLLBACK TRANSACTION
END

/* Create a recordset output if requested */
IF @sPrintMe = 'Y'
	SELECT @iRtnCode "RtnCode", @sRtnMsg "RtnMessage", @sOutput1 "OutPut1"

RETURN @iRtnCode
GO

GRANT EXECUTE ON spTemplate TO <ApplicableUser>
GO
